$set 3 #Configmenu

$ #ConfigOptions
# Konfiguran voby
$ #FocusModel
# Model zamerania
$ #WindowPlacement
# Umiestnenie okna
$ #ImageDithering
# Modifikcia farieb a jasu na obraze
$ #OpaqueMove
# Presvanie celho okna
$ #FullMax
# Pln maximalizcia
$ #FocusNew
# Zamera nov okn
$ #FocusLast
# Zamera okno pri zmene pracovnej plochy
$ #DisableBindings
# Zakza vzby s klvesou Scroll Lock
$ #ClickToFocus
# Klikn pre zameranie
$ #SloppyFocus
# Nedbanliv zameranie
$ #AutoRaise
# Automaticky presun do popredia
$ #ClickRaise
# Po kliknut presun do popredia
$ #SmartRows
# Inteligentn umiestnenie (riadky)
$ #SmartCols
# Inteligentn umiestnenie (stpce)
$ #Cascade
# Kaskdov umiestnenie
$ #LeftRight
# Zava doprava
$ #RightLeft
# Sprava doava
$ #TopBottom
# Zhora nadol
$ #BottomTop
# Zdola nahor
$ #NoDithering
# Do not dither images
$ #OrderedDithering
# Use fast dither
$ #FloydSteinbergDithering
# Use high-quality dither
